@@ -1,5 +1,7 @@
 var NAVTREEINDEX101 =
 {
+"namespacezypp_1_1solver_1_1detail.html#a8c33c57ee38fd4ec719339f5357c3533":[3,0,10,39,0,54],
+"namespacezypp_1_1solver_1_1detail.html#a9049667b6dea3109ffe4a5194005946d":[3,0,10,39,0,49],
 "namespacezypp_1_1solver_1_1detail.html#a929e271c57303057f74772ab5bab3884":[3,0,10,39,0,31],
 "namespacezypp_1_1solver_1_1detail.html#a9c29e8ab3519ca4e0ed2ed09f96e5266":[3,0,10,39,0,15],
 "namespacezypp_1_1solver_1_1detail.html#aa355ef2f7aebcd6488938458ed746a29":[3,0,10,39,0,41],
@@ -247,7 +249,5 @@ var NAVTREEINDEX101 =
 "namespacezypp_1_1ui.html#ab5e8444e8b42e908d3e13d06f8b25e6f":[3,0,10,45,20],
 "namespacezypp_1_1ui.html#acb7849bf45da7bbf289362bfdfccaeb7":[3,0,10,45,10],
 "namespacezypp_1_1ui.html#add6cc53e8d263bf3cf369fcecd6175c7":[3,0,10,45,23],
-"namespacezypp_1_1ui.html#ae04d33cc40f69459a21d3dec2ce35b44":[3,0,10,45,22],
-"namespacezypp_1_1ui_1_1selfilter.html":[3,0,10,45,0],
-"namespacezypp_1_1url.html":[3,0,10,46]
+"namespacezypp_1_1ui.html#ae04d33cc40f69459a21d3dec2ce35b44":[3,0,10,45,22]
 };
