@@ -1,5 +1,7 @@
 var NAVTREEINDEX112 =
 {
+"structzypp_1_1PluginFrame_1_1Impl.html#ae3bd62fc4d3d1d948b10d9278bfe7d2d":[4,0,7,170,0,21],
+"structzypp_1_1PluginFrame_1_1Impl.html#ae788cbcd7722024b9d3a9254ef2f036a":[3,0,10,179,0,13],
 "structzypp_1_1PluginFrame_1_1Impl.html#ae788cbcd7722024b9d3a9254ef2f036a":[4,0,7,170,0,13],
 "structzypp_1_1PluginFrame_1_1Impl.html#af7c009f6a520740e0731e1315523716a":[3,0,10,179,0,33],
 "structzypp_1_1PluginFrame_1_1Impl.html#af7c009f6a520740e0731e1315523716a":[4,0,7,170,0,33],
@@ -247,7 +249,5 @@ var NAVTREEINDEX112 =
 "structzypp_1_1ProvideFileOperation.html#aaa0276103131ee50de7af377905e0fec":[4,0,7,188,1],
 "structzypp_1_1PurgeKernels_1_1Impl.html":[3,0,10,199,0],
 "structzypp_1_1PurgeKernels_1_1Impl.html":[4,0,7,190,0],
-"structzypp_1_1PurgeKernels_1_1Impl.html#a1b9a22b926c4b2e49204bb9587d6820f":[3,0,10,199,0,9],
-"structzypp_1_1PurgeKernels_1_1Impl.html#a1b9a22b926c4b2e49204bb9587d6820f":[4,0,7,190,0,9],
-"structzypp_1_1PurgeKernels_1_1Impl.html#a209cdee77c7d15116c619818cd839c86":[3,0,10,199,0,14]
+"structzypp_1_1PurgeKernels_1_1Impl.html#a1b9a22b926c4b2e49204bb9587d6820f":[3,0,10,199,0,9]
 };
