@@ -1,5 +1,7 @@
 var NAVTREEINDEX115 =
 {
+"structzypp_1_1RepoManagerOptions.html#accedc7ade29ea2a89415820eec6d68e5":[4,0,7,195,3],
+"structzypp_1_1RepoManagerOptions.html#aec206f430c8a6e2975d98b6cc18f9f6e":[3,0,10,204,5],
 "structzypp_1_1RepoManagerOptions.html#aec206f430c8a6e2975d98b6cc18f9f6e":[4,0,7,195,5],
 "structzypp_1_1RepoManagerOptions.html#af1213b06f8423fd07b19c55a44dc4ee5":[3,0,10,204,0],
 "structzypp_1_1RepoManagerOptions.html#af1213b06f8423fd07b19c55a44dc4ee5":[4,0,7,195,0],
@@ -15,9 +17,9 @@ var NAVTREEINDEX115 =
 "structzypp_1_1RepoManager_1_1Impl.html#a5ac49e89087ea0fea352293214eca224":[4,0,7,194,0,10],
 "structzypp_1_1RepoManager_1_1Impl.html#a5d096aadf8009f048cd187aa2bedc43d":[3,0,10,203,0,1],
 "structzypp_1_1RepoManager_1_1Impl.html#a5d096aadf8009f048cd187aa2bedc43d":[4,0,7,194,0,1],
-"structzypp_1_1RepoManager_1_1Impl.html#a5ef0212b24d0ac117ef9aaee04b72826":[3,0,10,203,71],
+"structzypp_1_1RepoManager_1_1Impl.html#a5ef0212b24d0ac117ef9aaee04b72826":[3,0,10,203,72],
 "structzypp_1_1RepoManager_1_1Impl.html#a5ef0212b24d0ac117ef9aaee04b72826":[3,0,10,203,0,9],
-"structzypp_1_1RepoManager_1_1Impl.html#a5ef0212b24d0ac117ef9aaee04b72826":[4,0,7,194,71],
+"structzypp_1_1RepoManager_1_1Impl.html#a5ef0212b24d0ac117ef9aaee04b72826":[4,0,7,194,72],
 "structzypp_1_1RepoManager_1_1Impl.html#a5ef0212b24d0ac117ef9aaee04b72826":[4,0,7,194,0,9],
 "structzypp_1_1RepoManager_1_1Impl.html#a6024d7def0b76f3f0e282c473a85d29a":[3,0,10,203,0,8],
 "structzypp_1_1RepoManager_1_1Impl.html#a6024d7def0b76f3f0e282c473a85d29a":[4,0,7,194,0,8],
@@ -247,7 +249,5 @@ var NAVTREEINDEX115 =
 "structzypp_1_1SavingLocksReport.html#a4cc64e2170eaa980b88ff7c95e2346bd":[4,0,7,213,4],
 "structzypp_1_1SavingLocksReport.html#a60590ddb148513a2534108246109d850":[3,0,10,222,6],
 "structzypp_1_1SavingLocksReport.html#a60590ddb148513a2534108246109d850":[4,0,7,213,6],
-"structzypp_1_1SavingLocksReport.html#a66cfed0771f281327f30c9ec3a729aa4":[3,0,10,222,3],
-"structzypp_1_1SavingLocksReport.html#a66cfed0771f281327f30c9ec3a729aa4":[4,0,7,213,3],
-"structzypp_1_1SavingLocksReport.html#abb12dda821a75eea3b954a860a3c0861":[3,0,10,222,2]
+"structzypp_1_1SavingLocksReport.html#a66cfed0771f281327f30c9ec3a729aa4":[3,0,10,222,3]
 };
