@@ -1,5 +1,7 @@
 var NAVTREEINDEX116 =
 {
+"structzypp_1_1SavingLocksReport.html#a66cfed0771f281327f30c9ec3a729aa4":[4,0,7,213,3],
+"structzypp_1_1SavingLocksReport.html#abb12dda821a75eea3b954a860a3c0861":[3,0,10,222,2],
 "structzypp_1_1SavingLocksReport.html#abb12dda821a75eea3b954a860a3c0861":[4,0,7,213,2],
 "structzypp_1_1SavingLocksReport.html#abb12dda821a75eea3b954a860a3c0861a26ea51fda987f9d13c96a5a21c6a9fee":[3,0,10,222,2,1],
 "structzypp_1_1SavingLocksReport.html#abb12dda821a75eea3b954a860a3c0861a26ea51fda987f9d13c96a5a21c6a9fee":[4,0,7,213,2,1],
@@ -247,7 +249,5 @@ var NAVTREEINDEX116 =
 "structzypp_1_1base_1_1LogControlImpl.html#a1aed6d3bcd84865fd4c97669462d8d1e":[4,0,7,1,4,6],
 "structzypp_1_1base_1_1LogControlImpl.html#a1d34673639a53375b400febf76bf0a02":[3,0,10,2,5,5],
 "structzypp_1_1base_1_1LogControlImpl.html#a1d34673639a53375b400febf76bf0a02":[4,0,7,1,4,5],
-"structzypp_1_1base_1_1LogControlImpl.html#a27a9059e040d8739f7671cfe3f58b7cd":[3,0,10,2,5,23],
-"structzypp_1_1base_1_1LogControlImpl.html#a27a9059e040d8739f7671cfe3f58b7cd":[4,0,7,1,4,23],
-"structzypp_1_1base_1_1LogControlImpl.html#a2bd9a570abd6d59c3f9e7a0dcfed5a28":[3,0,10,2,5,26]
+"structzypp_1_1base_1_1LogControlImpl.html#a27a9059e040d8739f7671cfe3f58b7cd":[3,0,10,2,5,23]
 };
