@@ -1,5 +1,7 @@
 var NAVTREEINDEX117 =
 {
+"structzypp_1_1base_1_1LogControlImpl.html#a27a9059e040d8739f7671cfe3f58b7cd":[4,0,7,1,4,23],
+"structzypp_1_1base_1_1LogControlImpl.html#a2bd9a570abd6d59c3f9e7a0dcfed5a28":[3,0,10,2,5,26],
 "structzypp_1_1base_1_1LogControlImpl.html#a2bd9a570abd6d59c3f9e7a0dcfed5a28":[4,0,7,1,4,26],
 "structzypp_1_1base_1_1LogControlImpl.html#a2d683d51f92ff2cb964c5e02c6d0e40e":[3,0,10,2,5,3],
 "structzypp_1_1base_1_1LogControlImpl.html#a2d683d51f92ff2cb964c5e02c6d0e40e":[4,0,7,1,4,3],
@@ -247,7 +249,5 @@ var NAVTREEINDEX117 =
 "structzypp_1_1base_1_1logger_1_1LogControlImpl.html#ad79ff42d0a9ffe7891fadbf22abec468":[4,0,7,1,0,0,21],
 "structzypp_1_1base_1_1logger_1_1LogControlImpl.html#ae4dcd5172e9009b64d23191262f7d63a":[3,0,10,2,0,0,28],
 "structzypp_1_1base_1_1logger_1_1LogControlImpl.html#ae4dcd5172e9009b64d23191262f7d63a":[4,0,7,1,0,0,28],
-"structzypp_1_1base_1_1logger_1_1LogControlImpl.html#aef66b309729850b583804394cee3c6e6":[3,0,10,2,0,0,10],
-"structzypp_1_1base_1_1logger_1_1LogControlImpl.html#aef66b309729850b583804394cee3c6e6":[4,0,7,1,0,0,10],
-"structzypp_1_1base_1_1logger_1_1LogControlImpl.html#af61f746ad9de7f58de78a2320b14c6da":[3,0,10,2,0,0,34]
+"structzypp_1_1base_1_1logger_1_1LogControlImpl.html#aef66b309729850b583804394cee3c6e6":[3,0,10,2,0,0,10]
 };
