@@ -1,5 +1,7 @@
 var NAVTREEINDEX118 =
 {
+"structzypp_1_1base_1_1logger_1_1LogControlImpl.html#aef66b309729850b583804394cee3c6e6":[4,0,7,1,0,0,10],
+"structzypp_1_1base_1_1logger_1_1LogControlImpl.html#af61f746ad9de7f58de78a2320b14c6da":[3,0,10,2,0,0,34],
 "structzypp_1_1base_1_1logger_1_1LogControlImpl.html#af61f746ad9de7f58de78a2320b14c6da":[4,0,7,1,0,0,34],
 "structzypp_1_1base_1_1logger_1_1LogControlImpl.html#af80575041994ed483873fcd356cc01b1":[3,0,10,2,0,0,27],
 "structzypp_1_1base_1_1logger_1_1LogControlImpl.html#af80575041994ed483873fcd356cc01b1":[4,0,7,1,0,0,27],
@@ -247,7 +249,5 @@ var NAVTREEINDEX118 =
 "structzypp_1_1debug_1_1TraceCADBase.html#acdb48f944768ab3ea26b5454656caaa1af051c16192b8ee90b81cd18ab2bd0d8f":[4,0,7,4,4,0,0],
 "structzypp_1_1debug_1_1TraceCADBase.html#acdb48f944768ab3ea26b5454656caaa1afc6d70e8e313d9873676017818b62bc9":[3,0,10,5,4,0,2],
 "structzypp_1_1debug_1_1TraceCADBase.html#acdb48f944768ab3ea26b5454656caaa1afc6d70e8e313d9873676017818b62bc9":[4,0,7,4,4,0,2],
-"structzypp_1_1debug_1_1TraceCADBase.html#af130e40ed6c145ad971a8f3437d06345":[3,0,10,5,4,2],
-"structzypp_1_1debug_1_1TraceCADBase.html#af130e40ed6c145ad971a8f3437d06345":[4,0,7,4,4,2],
-"structzypp_1_1debug_1_1TraceLeave.html":[3,0,10,5,5]
+"structzypp_1_1debug_1_1TraceCADBase.html#af130e40ed6c145ad971a8f3437d06345":[3,0,10,5,4,2]
 };
