@@ -1,5 +1,7 @@
 var NAVTREEINDEX125 =
 {
+"structzypp_1_1sat_1_1SolvableType.html#a0d174b6ea5fc70d21addde39e325f71a":[4,0,7,31,15,80],
+"structzypp_1_1sat_1_1SolvableType.html#a116ade6dcedaf319ea948605c1eabab1":[3,0,10,37,14,49],
 "structzypp_1_1sat_1_1SolvableType.html#a116ade6dcedaf319ea948605c1eabab1":[4,0,7,31,15,49],
 "structzypp_1_1sat_1_1SolvableType.html#a14b302cf5d19fc6fdf9e4f3d11468b46":[3,0,10,37,14,47],
 "structzypp_1_1sat_1_1SolvableType.html#a14b302cf5d19fc6fdf9e4f3d11468b46":[4,0,7,31,15,47],
@@ -247,7 +249,5 @@ var NAVTREEINDEX125 =
 "structzypp_1_1sat_1_1Transaction_1_1Impl.html#a6165d82d23c90f9d85882b8c147b36a6":[4,0,7,31,18,1,28],
 "structzypp_1_1sat_1_1Transaction_1_1Impl.html#a7b627779eca352107baab7d4c711a5dd":[3,0,10,37,17,1,34],
 "structzypp_1_1sat_1_1Transaction_1_1Impl.html#a7b627779eca352107baab7d4c711a5dd":[4,0,7,31,18,1,34],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a7cecdd94f93d084e1aeb8a66ef9fc463":[3,0,10,37,17,1,38],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a7cecdd94f93d084e1aeb8a66ef9fc463":[4,0,7,31,18,1,38],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a823afb4255a20ffc2406c0712cc33516":[3,0,10,37,17,1,25]
+"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a7cecdd94f93d084e1aeb8a66ef9fc463":[3,0,10,37,17,1,38]
 };
