@@ -1,5 +1,7 @@
 var NAVTREEINDEX136 =
 {
+"zypp-core_2TriBool_8h.html":[5,0,1,30],
+"zypp-core_2TriBool_8h_source.html":[5,0,1,30],
 "zypp-core_2Url_8h.html":[5,0,1,32],
 "zypp-core_2Url_8h_source.html":[5,0,1,32],
 "zypp-core_2UserData_8h.html":[5,0,1,33],
@@ -247,7 +249,5 @@ var NAVTREEINDEX136 =
 "zyppglobal_8h.html#a5214a4b81377486aac76df2847693800":[5,0,1,6,1,20,18],
 "zyppglobal_8h.html#a5fb6e7721e6b06a6d78e93824d212b13":[5,0,1,6,1,20,15],
 "zyppglobal_8h.html#a5fcb5d81c33baa8958a954abdb945f87":[5,0,1,6,1,20,22],
-"zyppglobal_8h.html#a60c2c1d69c117fb1b17f6afae581f01c":[5,0,1,6,1,20,21],
-"zyppglobal_8h.html#a6a8d638ef9e763a445a988e59db7e607":[5,0,1,6,1,20,12],
-"zyppglobal_8h.html#a6d0b3aa3efdac41d2ea0722af6506af2":[5,0,1,6,1,20,2]
+"zyppglobal_8h.html#a60c2c1d69c117fb1b17f6afae581f01c":[5,0,1,6,1,20,21]
 };
