@@ -1,5 +1,7 @@
 var NAVTREEINDEX47 =
 {
+"classzypp_1_1json_1_1Number.html#aef01cda8c858d70245b6f82307ee2f25":[3,0,10,21,5,7],
+"classzypp_1_1json_1_1Number.html#aef01cda8c858d70245b6f82307ee2f25":[4,0,7,18,4,7],
 "classzypp_1_1json_1_1Number.html#aefc78e58ae346a00bec4bbc192fbf088":[3,0,10,21,5,4],
 "classzypp_1_1json_1_1Number.html#aefc78e58ae346a00bec4bbc192fbf088":[4,0,7,18,4,4],
 "classzypp_1_1json_1_1Object.html":[3,0,10,21,6],
@@ -247,7 +249,5 @@ var NAVTREEINDEX47 =
 "classzypp_1_1json_1_1Value.html#ad1bca2f17d90197d5673b8b8ecc878fd":[3,0,10,21,10,5],
 "classzypp_1_1json_1_1Value.html#ad1bca2f17d90197d5673b8b8ecc878fd":[4,0,7,18,9,5],
 "classzypp_1_1json_1_1Value.html#ad63d7473dbbdeb7557c3f09f748fdc68":[3,0,10,21,10,6],
-"classzypp_1_1json_1_1Value.html#ad63d7473dbbdeb7557c3f09f748fdc68":[4,0,7,18,9,6],
-"classzypp_1_1json_1_1Value.html#ad6bd5c5bd2464b24545a77eb4fa36b20":[3,0,10,21,10,0],
-"classzypp_1_1json_1_1Value.html#ad6bd5c5bd2464b24545a77eb4fa36b20":[4,0,7,18,9,0]
+"classzypp_1_1json_1_1Value.html#ad63d7473dbbdeb7557c3f09f748fdc68":[4,0,7,18,9,6]
 };
