@@ -1,5 +1,6 @@
 var NAVTREEINDEX7 =
 {
+"classztui_1_1PromptOptions.html#ac007d644af02e1903169fc33cddb20c0":[4,0,6,14,10],
 "classztui_1_1PromptOptions.html#adc18f4f53c1f5d8c42b49a6c5e0c308e":[3,0,9,17,13],
 "classztui_1_1PromptOptions.html#adc18f4f53c1f5d8c42b49a6c5e0c308e":[4,0,6,14,13],
 "classztui_1_1PromptOptions.html#ae47ad0eb28f09a25bed37cef7b50e5a0":[3,0,9,17,18],
@@ -248,6 +249,5 @@ var NAVTREEINDEX7 =
 "classztui_1_1ansi_1_1Color.html#a2e08a9c4c482079c8075041784dca724":[4,0,6,0,1,41],
 "classztui_1_1ansi_1_1Color.html#a383a4e3f557a040e02290a902f3377d9":[3,0,9,0,1,15],
 "classztui_1_1ansi_1_1Color.html#a383a4e3f557a040e02290a902f3377d9":[4,0,6,0,1,15],
-"classztui_1_1ansi_1_1Color.html#a45b0cdb96c1939540c6669ff87ff169c":[3,0,9,0,1,13],
-"classztui_1_1ansi_1_1Color.html#a45b0cdb96c1939540c6669ff87ff169c":[4,0,6,0,1,13]
+"classztui_1_1ansi_1_1Color.html#a45b0cdb96c1939540c6669ff87ff169c":[3,0,9,0,1,13]
 };
