@@ -1,5 +1,7 @@
 var NAVTREEINDEX92 =
 {
+"classzyppng_1_1WorkerCaps.html#adb4dd61ccb3049067d090e93bc20f980":[4,0,9,143,17],
+"classzyppng_1_1WorkerCaps.html#aeaace097c6b00f245dc4f4fc0349f6ca":[3,0,13,181,21],
 "classzyppng_1_1WorkerCaps.html#aeaace097c6b00f245dc4f4fc0349f6ca":[4,0,9,143,21],
 "classzyppng_1_1WorkerCaps.html#af39aa3e072beffd45fbc2e642a9f83d1":[3,0,13,181,15],
 "classzyppng_1_1WorkerCaps.html#af39aa3e072beffd45fbc2e642a9f83d1":[4,0,9,143,15],
@@ -247,7 +249,5 @@ var NAVTREEINDEX92 =
 "classzyppng_1_1repo_1_1RefreshContext.html#afc8e591b9e5ad0b63750e5567294c576":[4,0,9,5,1,0],
 "classzyppng_1_1worker_1_1DeviceDriver.html":[3,0,13,44,4],
 "classzyppng_1_1worker_1_1DeviceDriver.html":[4,0,9,6,4],
-"classzyppng_1_1worker_1_1DeviceDriver.html#a0564d2efb40a68f854a54f78cb282e08":[3,0,13,44,4,12],
-"classzyppng_1_1worker_1_1DeviceDriver.html#a0564d2efb40a68f854a54f78cb282e08":[4,0,9,6,4,12],
-"classzyppng_1_1worker_1_1DeviceDriver.html#a071555e42d58c5d6465a34fb1d76d2be":[3,0,13,44,4,8]
+"classzyppng_1_1worker_1_1DeviceDriver.html#a0564d2efb40a68f854a54f78cb282e08":[3,0,13,44,4,12]
 };
