@@ -1,5 +1,7 @@
 var NAVTREEINDEX93 =
 {
+"classzyppng_1_1worker_1_1DeviceDriver.html#a0564d2efb40a68f854a54f78cb282e08":[4,0,9,6,4,12],
+"classzyppng_1_1worker_1_1DeviceDriver.html#a071555e42d58c5d6465a34fb1d76d2be":[3,0,13,44,4,8],
 "classzyppng_1_1worker_1_1DeviceDriver.html#a071555e42d58c5d6465a34fb1d76d2be":[4,0,9,6,4,8],
 "classzyppng_1_1worker_1_1DeviceDriver.html#a0be42c0d96bd73b23323d1d3cb0f9fef":[3,0,13,44,4,18],
 "classzyppng_1_1worker_1_1DeviceDriver.html#a0be42c0d96bd73b23323d1d3cb0f9fef":[4,0,9,6,4,18],
@@ -247,7 +249,5 @@ var NAVTREEINDEX93 =
 "credentialmanager_8h_source.html":[5,0,3,0,5],
 "curlauthdata_8cc.html":[5,0,2,0,0],
 "curlauthdata_8cc_source.html":[5,0,2,0,0],
-"curlauthdata_8h.html":[5,0,2,0,1],
-"curlauthdata_8h_source.html":[5,0,2,0,1],
-"curlconfig_8cc.html":[5,0,2,5]
+"curlauthdata_8h.html":[5,0,2,0,1]
 };
