@@ -1,5 +1,7 @@
 var NAVTREEINDEX94 =
 {
+"curlauthdata_8h_source.html":[5,0,2,0,1],
+"curlconfig_8cc.html":[5,0,2,5],
 "curlconfig_8cc.html#a243c39db05fce10d8f918665f9eebacb":[5,0,2,5,0],
 "curlconfig_8cc_source.html":[5,0,2,5],
 "curlconfig_8h.html":[5,0,2,6],
@@ -247,7 +249,5 @@ var NAVTREEINDEX94 =
 "functions_type_f.html":[4,3,3,5],
 "functions_type_h.html":[4,3,3,6],
 "functions_type_i.html":[4,3,3,7],
-"functions_type_j.html":[4,3,3,8],
-"functions_type_k.html":[4,3,3,9],
-"functions_type_l.html":[4,3,3,10]
+"functions_type_j.html":[4,3,3,8]
 };
