@@ -1,5 +1,7 @@
 var NAVTREEINDEX97 =
 {
+"namespaceztui_1_1mbs.html":[3,0,9,4],
+"namespaceztui_1_1out.html":[3,0,9,5],
 "namespaceztui_1_1out.html#a01edf5c2cea70f10755afad4158a7676":[3,0,9,5,19],
 "namespaceztui_1_1out.html#a18d5eea08523e416a7bd632a90ecefd0":[3,0,9,5,9],
 "namespaceztui_1_1out.html#a1f025d0bbe15e928e5148c6e2f592d45":[3,0,9,5,21],
@@ -247,7 +249,5 @@ var NAVTREEINDEX97 =
 "namespacezypp.html#a786df3cf123484fbee62a0b6023ccdb3":[3,0,10,841],
 "namespacezypp.html#a7abb7cd6847874a1b589b6a1e16379a6":[3,0,10,382],
 "namespacezypp.html#a7c6c36111c52dde2fa60b7c9dcb7f247":[3,0,10,634],
-"namespacezypp.html#a7c6f91d0fd4fdeadb739ec1fd0c3375e":[3,0,10,295],
-"namespacezypp.html#a7cce3d6f533245e1710eadbe0909ec12":[3,0,10,608],
-"namespacezypp.html#a7dab952ab3fa93f989196b9c5983545d":[3,0,10,405]
+"namespacezypp.html#a7c6f91d0fd4fdeadb739ec1fd0c3375e":[3,0,10,295]
 };
