@@ -1,5 +1,7 @@
 var NAVTREEINDEX98 =
 {
+"namespacezypp.html#a7cce3d6f533245e1710eadbe0909ec12":[3,0,10,608],
+"namespacezypp.html#a7dab952ab3fa93f989196b9c5983545d":[3,0,10,405],
 "namespacezypp.html#a7e90ee3d56a61dc608dbaafda680ff3a":[3,0,10,573],
 "namespacezypp.html#a7f9f7b4311f6ca475d48f6ed9e509444":[3,0,10,298],
 "namespacezypp.html#a800c137e3574b83fd96784fe47f6d781":[3,0,10,587],
@@ -247,7 +249,5 @@ var NAVTREEINDEX98 =
 "namespacezypp_1_1base.html#a24b0882e23829160798494569410f8df":[3,0,10,2,17],
 "namespacezypp_1_1base.html#a54fb9661def1e8ebfba39a110a93c2a0":[3,0,10,2,15],
 "namespacezypp_1_1base.html#a975be5c3afb0c831a1451e819ca9787b":[3,0,10,2,16],
-"namespacezypp_1_1base.html#ab051dd95fba5221a2140778c3f9ed8d5":[3,0,10,2,20],
-"namespacezypp_1_1base.html#add098b25074e1524ec60165df6f384b0":[3,0,10,2,18],
-"namespacezypp_1_1base.html#aeabfa9455b85032a19aecf889aba285a":[3,0,10,2,14]
+"namespacezypp_1_1base.html#ab051dd95fba5221a2140778c3f9ed8d5":[3,0,10,2,20]
 };
